==> kbibtex-0.2.3.tar.bz2: kbibtex-0.2.3/src/webqueryarxiv.h <==
/***************************************************************************
 *   Copyright (C) 2004-2009 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KBIBTEXWEBQUERYARXIV_H
#define KBIBTEXWEBQUERYARXIV_H

#include <qstring.h>
#include <qstringlist.h>
#include <qregexp.h>

#include <kio/job.h>

#include <fileimporterbibtex.h>
#include <webquery.h>

class QBuffer;

namespace KBibTeX
{
    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryArXivWidget : public WebQueryWidget
    {
        Q_OBJECT
    public:
        WebQueryArXivWidget( QWidget *parent, const char *name = 0 );
    };

    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryArXiv : public WebQuery
    {
        Q_OBJECT
    public:
        WebQueryArXiv( QWidget* parent );
        virtual ~WebQueryArXiv();

        void query();

        QString title();
        QString disclaimer();
        QString disclaimerURL();

        WebQueryWidget *widget();

    protected:
        void cancelQuery();

    private slots:
        void arXivResult( KIO::Job *job );
        void arXivAbstractResult( KIO::Job *job );

    private:
        QString m_lastHit;
        BibTeX::FileImporterBibTeX *m_importer;
        QString m_arXivServer;
        int m_numberOfResults, m_totalHits, m_receivedHits;
        KIO::Job* m_currentJob;
        QValueList<KURL> m_urls;
        WebQueryArXivWidget *m_widget;

        QRegExp m_jourRef1, m_jourRef2, m_jourRef3, m_jourRef4, m_jourRef5, m_jourRef6;
    };
}

#endif

==> kbibtex_0.2.3.90.orig.tar.bz2: kbibtex-0.2.3.90/src/webqueryarxiv.h <==
/***************************************************************************
 *   Copyright (C) 2004-2009 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KBIBTEXWEBQUERYARXIV_H
#define KBIBTEXWEBQUERYARXIV_H

#include <qstring.h>
#include <qstringlist.h>
#include <qregexp.h>

#include <kio/job.h>

#include <fileimporterbibtex.h>
#include <webquery.h>

class QBuffer;

namespace KBibTeX
{
    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryArXivWidget : public WebQueryWidget
    {
        Q_OBJECT
    public:
        WebQueryArXivWidget( QWidget *parent, const char *name = 0 );
    };

    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryArXiv : public WebQuery
    {
        Q_OBJECT
    public:
        WebQueryArXiv( QWidget* parent );
        virtual ~WebQueryArXiv();

        void query();

        QString title();
        QString disclaimer();
        QString disclaimerURL();

        WebQueryWidget *widget();

        void fetchFromAbstract( const KURL &abstractURL );

    protected:
        void cancelQuery();

    private slots:
        void arXivResult( KIO::Job *job );
        void unlockJob( KIO::Job *job );
        void arXivAbstractResult( KIO::Job *job );

    private:
        QString m_lastHit;
        BibTeX::FileImporterBibTeX *m_importer;
        QString m_arXivServer;
        int m_numberOfResults, m_totalHits, m_receivedHits;
        QMutex m_currentJobMutex;
        QValueList<KURL> m_urls;
        WebQueryArXivWidget *m_widget;

        QRegExp m_jourRef1, m_jourRef2, m_jourRef3, m_jourRef4, m_jourRef5, m_jourRef6, m_reJour, m_reYear, m_rePages;
    };
}

#endif
